@@ -2,15 +2,17 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'LDAP Authentication',
+    'name_bg_BG' : 'LDAP Проверка',
     'name_de_DE' : 'LDAP Authentifizierung',
     'name_es_CO': 'Autentificación LDAP',
     'name_es_ES': 'Autentificación LDAP',
     'name_fr_FR': 'Authentification LDAP',
-    'version': '1.8.1',
+    'version': '2.0.1',
     'author': 'B2CK, Josh Dukes & Udo Spallek',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
     'description': '''Authenticate users with LDAP server.''',
+    'description_bg_BG': 'Проверка на потребители чрез LDAP сървър.',
     'description_de_DE' : '''Authentifizierung über LDAP
     - Fügt Unterstützung für Authentifizierung über einen LDAP-Server hinzu.
 ''',
@@ -26,6 +28,7 @@
         'connection.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
